# CLI Plugins

CLI Plugins provide default handling for the most common lifecycle events during Mountaineer development. Import these if convenient, otherwise you can follow our implementation approaches to implement your own.

## Webapp CLI

::: mountaineer.cli.handle_runserver

::: mountaineer.cli.handle_watch

::: mountaineer.cli.handle_build

## Database CLI

::: mountaineer.database.cli.handle_createdb
